@@ -545,9 +545,12 @@ NB_BASE = {
 
 def main():
     cmd = sys.argv[1]
-    if cmd not in {"nb2py", "py2nb", "count_loc"}:
+    commands = {"py2md", "nb2md", "nb2py", "py2nb", "count_loc"}
+    if cmd not in commands:
         raise ValueError(
             "Specify a command: either "
+            "`py2md source_file.py out_file.md` or "
+            "`nb2md source_file.ipynb out_file.md` or "
             "`nb2py source_filename.ipynb target_filename.py` or "
             "`py2nb source_filename.py target_file name.ipynb` or "
             "`count_loc source_filename.py`."
@@ -562,6 +565,26 @@ def main():
         source = sys.argv[2]
         target = sys.argv[3]
 
+        if cmd == "nb2md":
+            if not source.endswith(".ipynb"):
+                raise ValueError(
+                    f"The source filename should be a Notebook file. Got: {source}"
+                )
+            if not target.endswith(".md"):
+                raise ValueError(
+                    f"The target filename should be a Markdown file. Got: {target}"
+                )
+            nb_to_md(source, target)
+        if cmd == "py2md":
+            if not source.endswith(".py"):
+                raise ValueError(
+                    f"The source filename should be a Python file. Got: {source}"
+                )
+            if not target.endswith(".md"):
+                raise ValueError(
+                    f"The target filename should be a Markdown file. Got: {target}"
+                )
+            py_to_md(source, target)
         if cmd == "py2nb":
             if not source.endswith(".py"):
                 raise ValueError(
